@@ -18,7 +18,7 @@
 # You should have received a copy of
 # the GNU Lesser General Public License
 # along with DevOrSysAdminScripts.
-# If not, see <http://www.gnu.org/licenses/>.
+# If not, see <https://www.gnu.org/licenses/>.
 #
 # ©Copyright 2023-2024 Laurent Lyaudet
 
@@ -28,7 +28,7 @@ wget_sha512(){
   # $3 correct_sha512
   if [[ ! -f "$1" ]];
   then
-    wget "$2"
+    wget -O "$1" "$2"
   fi
   present_sha512=$(sha512sum "$1" | cut -f1 -d' ')
   if [[ "$present_sha512" != "$3" ]];
